{ config, lib, pkgs, ... }:
{
  users.users."${config.vars.mainUser}" = {
    isNormalUser = true;
    createHome = true;
    linger = true;
    hashedPassword = config.secrets.accPass.main;
    openssh.authorizedKeys.keyFiles = [
      # Special keys
      ./warden.pub
      ./pixel9.pub

      # Host keys
      ../../../../hosts/tower/id_ed25519.pub
      ../../../../hosts/intuos/id_ed25519.pub
      ../../../../hosts/jupiter/id_ed25519.pub
      ../../../../hosts/flight/id_ed25519.pub
    ];
    extraGroups = [
      # Privilige
      "wheel"

      # Devices
      "audio"
      "input"
      "render"
      "rtkit"
      "video"

      # Virtualization
      "incus-admin"
      "kvm"
      "libvirtd"
      "qemu-libvirtd"

      # Services
      "minecraft"
      "nfsShare"
      "nginx"
    ];
    shell = pkgs.zsh;
    uid = 1000;
  };

  # Import hm config, enable profiles based on system tags
  home-manager.users."${config.vars.mainUser}" = {
    imports = [ ../../../home ];
    home = {
      desktop.enable = builtins.elem "pc" config.system.nixos.tags;
      chat.enable = builtins.elem "chat" config.system.nixos.tags;
      gaming.enable = builtins.elem "gaming" config.system.nixos.tags;
      production.enable = builtins.elem "production" config.system.nixos.tags;
      school.enable = builtins.elem "school" config.system.nixos.tags;
      stateVersion = lib.mkForce config.system.stateVersion;
    };
  };
}
